![Logo](https://raw.githubusercontent.com/datatrails/datatrails-scitt-samples/main/DataTrails_Horizontal_Logo_Black.png#gh-light-mode-only)
![Logo](https://raw.githubusercontent.com/datatrails/datatrails-scitt-samples/main/DataTrails_Horizontal_Logo_White.png#gh-dark-mode-only)

# DataTrails SCITT Examples

The files in this repository can be used to demonstrate how the DataTrails SCITT API works.

For usage, please see [Quickstart: SCITT Statements (Preview)](https://docs.datatrails.ai/developers/developer-patterns/scitt-api/)

The python package produced by this repository is tested to a production standard.

Its purpose is to provide a clear example of how to use the current DataTrails SCITT API's,
as such, no promise of backwards compatibility is given.

Developers are encouraged to use the sources in this repositor as reference
material for their own integrations.